@@ -36,6 +36,15 @@ except NameError:
 EXECUTION_RESULT_OK = 0
 EXECUTION_RESULT_NOK = 1
 
+URL_RE = re.compile(
+    r'^https?://' # http:// or https://
+    r'(?:(?:[A-Z0-9](?:[A-Z0-9-]{0,61}[A-Z0-9])?\.)+'
+    r'(?:[A-Z]{2,6}\.?|[A-Z0-9-]{2,}\.?)|' # domain...
+    r'localhost|' # localhost...
+    r'\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3}|' # ...or ipv4
+    r'\[?[A-F0-9]*:[A-F0-9:]+\]?)' # ...or ipv6
+    r'(?::\d+)?' # optional port
+    r'(?:/?|[/?]\S+)$', re.IGNORECASE)
 
 def get_ip():
     """Return the machine external IP.
@@ -58,7 +67,7 @@ def execute_update(args):
 
     provider_class = getattr(dnsupdater,
                              dnsupdater.AVAILABLE_PLUGINS.get(args.provider))
-
+    updater_options = {}
     process_message = None
     exec_result = EXECUTION_RESULT_NOK
     update_ddns = False
@@ -113,8 +122,22 @@ def execute_update(args):
                           "provided via command line or stored with --store " \
                           "option.\nExecute noipy --help for more details."
 
+    if update_ddns and args.provider == 'generic':
+        if args.url:
+            if not URL_RE.match(args.url):
+                process_message = "Malformed url"
+                exec_result = EXECUTION_RESULT_NOK
+                update_ddns = False
+            else:
+                updater_options['url'] = args.url 
+        else:
+            process_message = "Must use --url if --provider is 'generic' " \
+                              "(default)"
+            exec_result = EXECUTION_RESULT_NOK
+            update_ddns = False
+
     if update_ddns:
-        updater = provider_class(auth, args.hostname)
+        updater = provider_class(auth, args.hostname, updater_options)
         ip_address = args.ip if args.ip else get_ip()
         print("Updating hostname '%s' with IP address %s [provider: '%s']..."
               % (args.hostname, ip_address, args.provider))
@@ -135,6 +158,7 @@ def create_parser():
                                            % dnsupdater.DEFAULT_PLUGIN,
                         choices=dnsupdater.AVAILABLE_PLUGINS.keys(),
                         default=dnsupdater.DEFAULT_PLUGIN)
+    parser.add_argument('--url',help="custom DDNS server address")
     parser.add_argument('--store',
                         help="store DDNS authentication information and "
                              "update the hostname if it is provided",
